# HG changeset patch
# User Toshi MARUYAMA
# Parent 4926092388013cb6434c914318a3c084f86a18c4
qnew

diff --git a/Rakefile b/Rakefile
--- a/Rakefile
+++ b/Rakefile
@@ -5,6 +5,11 @@ require(File.join(File.dirname(__FILE__)
 
 require 'rake'
 require 'rake/testtask'
-require 'rdoc/task'
+
+begin
+  require 'rdoc/task'
+rescue LoadError
+  # RDoc is not available
+end
 
 require 'tasks/rails'
diff --git a/lib/tasks/documentation.rake b/lib/tasks/documentation.rake
--- a/lib/tasks/documentation.rake
+++ b/lib/tasks/documentation.rake
@@ -12,23 +12,25 @@
 # See doc/COPYRIGHT.rdoc for more details.
 #++
 
-#clear the doc:app task et al
-Rake::Task["doc:app"].clear
-Rake::Task["doc/app"].clear
-Rake::Task["doc/app/index.html"].clear
+if Rake::Task.task_defined?("doc:app")
+  # clear the doc:app task et al
+  Rake::Task["doc:app"].clear
+  Rake::Task["doc/app"].clear
+  Rake::Task["doc/app/index.html"].clear
 
-namespace :doc do
-  desc "Generate documentation for the application. Set custom template with TEMPLATE=/path/to/rdoc/template.rb or title with TITLE=\"Custom Title\""
-  RDoc::Task.new("app") { |rdoc|
-    rdoc.rdoc_dir = 'doc/app'
-    rdoc.template = ENV['template'] if ENV['template']
-    rdoc.title    = ENV['title'] || "ChiliProject"
-    rdoc.options << '--line-numbers' << '--inline-source'
-    rdoc.options << '--charset' << 'utf-8'
-    rdoc.rdoc_files.include('app/**/*.rb')
-    rdoc.rdoc_files.include('lib/**/*.rb')
-    rdoc.rdoc_files.include('README.rdoc')
-    rdoc.rdoc_files.include('doc/*.rdoc')
-    rdoc.main = 'README.rdoc'
-  }
+  namespace :doc do
+    desc "Generate documentation for the application. Set custom template with TEMPLATE=/path/to/rdoc/template.rb or title with TITLE=\"Custom Title\""
+    RDoc::Task.new("app") { |rdoc|
+      rdoc.rdoc_dir = 'doc/app'
+      rdoc.template = ENV['template'] if ENV['template']
+      rdoc.title    = ENV['title'] || "ChiliProject"
+      rdoc.options << '--line-numbers' << '--inline-source'
+      rdoc.options << '--charset' << 'utf-8'
+      rdoc.rdoc_files.include('app/**/*.rb')
+      rdoc.rdoc_files.include('lib/**/*.rb')
+      rdoc.rdoc_files.include('README.rdoc')
+      rdoc.rdoc_files.include('doc/*.rdoc')
+      rdoc.main = 'README.rdoc'
+    }
+  end
 end
